@@ -11,7 +11,7 @@ pub(crate) fn create(package: &str) -> Result<Box<dyn Command>, ScriptError> {
     let name = pckg::concat(package, "SetModeGlob");
     let command = create_alias_command(
         name,
-        vec!["glob_chmod".to_string()],
+        vec!["glob_chmod".to_string(), "chmod_glob".to_string()],
         include_str!("help.md").to_string(),
         "glob_chmod".to_string(),
         include_str!("script.ds").to_string(),
