@@ -15,6 +15,8 @@ mod net;
 mod noop;
 mod not;
 pub(crate) mod on_error;
+mod print;
+mod println;
 mod process;
 mod random;
 mod read;
@@ -39,6 +41,8 @@ pub(crate) fn load(commands: &mut Commands) -> Result<(), ScriptError> {
     commands.set(man::create(PACKAGE))?;
     commands.set(noop::create(PACKAGE))?;
     commands.set(not::create(PACKAGE))?;
+    commands.set(print::create(PACKAGE))?;
+    commands.set(println::create(PACKAGE)?)?;
     commands.set(read::create(PACKAGE))?;
     commands.set(release::create(PACKAGE))?;
 
